@@ -1,7 +1,7 @@
 package App::riap;
 
-our $DATE = '2016-02-03'; # DATE
-our $VERSION = '0.34'; # VERSION
+our $DATE = '2016-03-10'; # DATE
+our $VERSION = '0.35'; # VERSION
 
 use 5.010001;
 use strict;
@@ -181,8 +181,8 @@ sub colorize {
 sub _json_obj {
     state $json;
     if (!$json) {
-        require JSON;
-        $json = JSON->new->allow_nonref;
+        require JSON::MaybeXS;
+        $json = JSON::MaybeXS->new->allow_nonref;
     }
     $json;
 }
@@ -737,7 +737,7 @@ App::riap - Riap command-line client shell
 
 =head1 VERSION
 
-version 0.34
+version 0.35
 
 =head1 SYNOPSIS
 
